package com.displaynone.acss.components.acs.models.visit.repository

import android.util.Log
import com.displaynone.acss.components.acs.models.visit.repository.dto.LastVisitsDto
import com.displaynone.acss.config.Constants.serverUrl
import com.displaynone.acss.config.Network
import io.ktor.client.call.body
import io.ktor.client.request.get
import io.ktor.client.request.headers
import io.ktor.client.request.setBody
import io.ktor.client.statement.bodyAsText
import io.ktor.http.HttpHeaders
import io.ktor.http.HttpStatusCode
import io.ktor.http.encodeURLPath
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext

class VisitRepository {

    suspend fun getMyLastVisits(pageNum: Int,
                                pageSize: Int,
                                token: String): Result<LastVisitsDto> = withContext(Dispatchers.IO){
        runCatching {
            val result = Network.client.get("$serverUrl/api/acs/visits/me?page=$pageNum&size=$pageSize") {
                headers {
                    append(HttpHeaders.Authorization, "Bearer $token")
                }
            }
            Log.d("VisitRepository", result.bodyAsText())
            if (result.status != HttpStatusCode.OK) {
                error("Status ${result.status}: ${result.body<String>()}")
            }

            result.body()
        }
    }
    suspend fun getLastVisitsByLogin(pageNum: Int,
                                     pageSize: Int,
                                     token: String, login: String): Result<LastVisitsDto> = withContext(
        Dispatchers.IO){
        runCatching {
            Log.d("VisitRepository", login)
            val encodedLogin = login.encodeURLPath()
            val result = Network.client.get("$serverUrl/api/acs/visits/login/${encodedLogin}?page=$pageNum&size=$pageSize") {
                headers {
                    append(HttpHeaders.Authorization, "Bearer $token")
                }
                setBody("""{ "login": "$encodedLogin" }""")
            }
            if (result.status != HttpStatusCode.OK) {
                error("Status ${result.status}: ${result.body<String>()}")
            }
            Log.d("VisitRepository", result.bodyAsText())
            result.body()
        }
    }
}